==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/LegendBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseButtonEventArgsDescriptionMetadata } from "./LegendMouseButtonEventArgsDescriptionMetadata";
import { LegendMouseEventArgsDescriptionMetadata } from "./LegendMouseEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var LegendBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(LegendBaseDescriptionMetadata, _super);
    function LegendBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LegendBaseDescriptionMetadata.e = function (a) {
        a.item("Background", "(wf:BackColor/ColorTransform)Brush");
    };
    LegendBaseDescriptionMetadata.b = function (a) {
        if (LegendBaseDescriptionMetadata.a == null) {
            LegendBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LegendBaseDescriptionMetadata.c(LegendBaseDescriptionMetadata.a);
        }
        if (a.j(LegendBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(LegendBaseDescriptionMetadata.a);
        LegendMouseButtonEventArgsDescriptionMetadata.d(a);
        LegendMouseEventArgsDescriptionMetadata.d(a);
    };
    LegendBaseDescriptionMetadata.c = function (a) {
        a.item("LegendItemMouseLeftButtonDownRef", "EventRef::legendItemMouseLeftButtonDown");
        a.item("LegendItemMouseLeftButtonUpRef", "EventRef::legendItemMouseLeftButtonUp");
        a.item("LegendItemMouseEnterRef", "EventRef::legendItemMouseEnter");
        a.item("LegendItemMouseLeaveRef", "EventRef::legendItemMouseLeave");
        a.item("LegendItemMouseMoveRef", "EventRef::legendItemMouseMove");
        LegendBaseDescriptionMetadata.e(a);
    };
    LegendBaseDescriptionMetadata.d = function (a) {
        LegendBaseDescriptionMetadata.b(a);
        a.z("LegendBase", LegendBaseDescriptionMetadata.a);
    };
    LegendBaseDescriptionMetadata.$t = markType(LegendBaseDescriptionMetadata, 'LegendBaseDescriptionMetadata');
    LegendBaseDescriptionMetadata.a = null;
    return LegendBaseDescriptionMetadata;
}(Base));
export { LegendBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/LegendBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseButtonEventArgsDescriptionMetadata } from "./LegendMouseButtonEventArgsDescriptionMetadata";
import { LegendMouseEventArgsDescriptionMetadata } from "./LegendMouseEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var LegendBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(LegendBaseDescriptionMetadata, _super);
    function LegendBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LegendBaseDescriptionMetadata.e = function (a) {
        a.item("Background", "(wf:BackColor/ColorTransform)Brush");
    };
    LegendBaseDescriptionMetadata.b = function (a) {
        if (LegendBaseDescriptionMetadata.a == null) {
            LegendBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LegendBaseDescriptionMetadata.c(LegendBaseDescriptionMetadata.a);
        }
        if (a.k(LegendBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(LegendBaseDescriptionMetadata.a);
        LegendMouseButtonEventArgsDescriptionMetadata.d(a);
        LegendMouseEventArgsDescriptionMetadata.d(a);
    };
    LegendBaseDescriptionMetadata.c = function (a) {
        a.item("LegendItemMouseLeftButtonDownRef", "EventRef::legendItemMouseLeftButtonDown");
        a.item("LegendItemMouseLeftButtonUpRef", "EventRef::legendItemMouseLeftButtonUp");
        a.item("LegendItemMouseEnterRef", "EventRef::legendItemMouseEnter");
        a.item("LegendItemMouseLeaveRef", "EventRef::legendItemMouseLeave");
        a.item("LegendItemMouseMoveRef", "EventRef::legendItemMouseMove");
        LegendBaseDescriptionMetadata.e(a);
    };
    LegendBaseDescriptionMetadata.d = function (a) {
        LegendBaseDescriptionMetadata.b(a);
        a.ab("LegendBase", LegendBaseDescriptionMetadata.a);
    };
    LegendBaseDescriptionMetadata.$t = markType(LegendBaseDescriptionMetadata, 'LegendBaseDescriptionMetadata');
    LegendBaseDescriptionMetadata.a = null;
    return LegendBaseDescriptionMetadata;
}(Base));
export { LegendBaseDescriptionMetadata };
